summaryrefslogtreecommitdiffstats
path: root/karm/plannerparser.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'karm/plannerparser.cpp')
-rw-r--r--karm/plannerparser.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/karm/plannerparser.cpp b/karm/plannerparser.cpp
index a1f83eb2..b205fd7a 100644
--- a/karm/plannerparser.cpp
+++ b/karm/plannerparser.cpp
@@ -67,13 +67,13 @@ test cases:
}
// at the moment, task is still the old task or the old father task (if an endElement occurred) or not existing (if the
// new task is a top-level-task). Make task the tqparenttask, if existing.
DesktopList dl;
if (level++>0)
{
- tqparentTask=task;
- task = new Task(taskName, 0, 0, dl, tqparentTask);
- task->setUid(_taskView->storage()->addTask(task, tqparentTask));
+ parentTask=task;
+ task = new Task(taskName, 0, 0, dl, parentTask);
+ task->setUid(_taskView->storage()->addTask(task, parentTask));
}
else
{
@@ -67,13 +67,13 @@ test cases:
}
// at the moment, task is still the old task or the old father task (if an endElement occurred) or not existing (if the
- // new task is a top-level-task). Make task the tqparenttask, if existing.
+ // new task is a top-level-task). Make task the parenttask, if existing.
DesktopList dl;
if (level++>0)